package ur_rna.Utilities;

import java.io.PrintStream;

/**
 * Created by Richard
 */
public class AppLog {
    protected static PrintStream nullStream = new NullPrintStream();
    public static Verbosity DefaultLogImportance = Verbosity.Info;
    private static AppLog defaultAppLog;
    public static AppLog getDefault() {
        if (defaultAppLog == null)
            defaultAppLog = new AppLog();
        return defaultAppLog;
    }
    public static void setDefault(AppLog defLog) {
        defaultAppLog = defLog;
    }

    public AppLog() {
        readSystemProperties();
    }

    public void readSystemProperties() {
        setDebug(Convert.toBool(System.getProperty("debug")));
        setVerbosity(Convert.toInt(System.getProperty("verbose", ""+DefaultLogImportance.importance), DefaultLogImportance.importance));
    }
    public boolean isTraceEnabled() { return Verbosity.Trace.importance <= _requiredVerbosity.importance; }
    public boolean isDebugEnabled() { return Verbosity.Debug.importance <= _requiredVerbosity.importance || _debug; }

    public boolean isEnabled(final Verbosity verbosity) {
        return verbosity.importance <= _requiredVerbosity.importance;
    }

    protected boolean _debug = false;
    protected Verbosity _requiredVerbosity = Verbosity.Info;


//    /* Use of the following stream references allows the application to easily redirect. */
    private PrintStream[] streams = new PrintStream[] {
        new NullPrintStream(), System.err,  System.err, System.out, System.out, System.out
    };

    public boolean getDebug() { return _debug; }
    public void setDebug(boolean value) { _debug = value; }

    public Verbosity getVerbosity() { return _requiredVerbosity; }
    public void setVerbosity(int value) throws IllegalArgumentException {
        _requiredVerbosity = Verbosity.fromImportance(value);
    }
    public void setVerbosity(Verbosity value) throws IllegalArgumentException {
        getStream(value); //throws error if invalid.
        _requiredVerbosity = value;
    }

    public void log(String s) {
        log(s, DefaultLogImportance);
    }
    public void log(String format, Object ... args) {
        logFmt(format, DefaultLogImportance, args);
    }
    private void logFmt(String format, Verbosity importance, Object ... args) {
        if (args == null || args.length == 0)
            log(format, importance);
        else
            log(String.format(format, args), importance);
    }
    public void log(String s, Verbosity messageVerbosity) {
        try {
            getStream(messageVerbosity).println(s);
        } catch (Throwable e) {
            e.printStackTrace(System.err);
            System.err.println(s);
        }
    }

    public PrintStream getStream(Verbosity streamVerbosity) {
        int i = streamVerbosity.importance;
        if (i < 0 || i >= streams.length)
            throw new InternalError("Invalid log type: " + i); //should never happen because it is not one of the defined values.
        if (i <= _requiredVerbosity.importance || _debug && i <= Verbosity.Debug.importance)
            return streams[streamVerbosity.importance];
        return nullStream;
    }

    public PrintStream getDbgStream() { return getStream(Verbosity.Debug); }
    public PrintStream getErrStream() { return getStream(Verbosity.Error); }
    public PrintStream getTrStream() { return getStream(Verbosity.Trace); }

    public void trace(String s) { log(s, Verbosity.Trace); }
    public void debug(String s) { log(s, Verbosity.Debug); }
    public void info(String s) { log(s, Verbosity.Info); }
    public void warn(String s) { log(s, Verbosity.Warn); }
    public void error(String s) { log(s, Verbosity.Error); }

    public void trace(String format, Object... args) { logFmt(format, Verbosity.Trace, args); }
    public void debug(String format, Object... args) { logFmt(format, Verbosity.Debug, args); }
    public void info(String format, Object... args) { logFmt(format, Verbosity.Info, args); }
    public void warn(String format, Object... args) { logFmt(format, Verbosity.Warn, args); }
    public void error(String format, Object... args) { logFmt(format, Verbosity.Error, args); }
    public void error(String s, Throwable e) { log(s, Verbosity.Error); log(getErrorInfo(e), Verbosity.Error); }

    public static String getErrorInfo(Throwable t) {
        java.io.StringWriter sw = new java.io.StringWriter();
        t.printStackTrace(new java.io.PrintWriter(sw));
        return sw.toString();
    }
}
